@@ -75,9 +75,9 @@ void DesktopConfig::setDefaults()
     startSnapTop = startSnapLeft = true;
     
     fileBackground = "None";
-    colorBackground = "#A2CD70";
+    colorBackground = "None";
     sourceBackground = "None";
-    delayBackground = 5; //Five minutes
+    delayBackground = 0; //Default Inactive
     modeBackground = "STRETCH";
     
     transparency = 0;
@@ -163,12 +163,12 @@ void DesktopConfig::setDesktopOnlyOptions(Table table)
       //Delay Background
       if (table.Query("Background.Delay") != "")
 	      delayBackground  = atoi(table.Query("Background.Delay").c_str());
-      //Max one day
-      if(delayBackground > 1440) 
-	      delayBackground = 1440;
-      //Min 1 minute
-      if(delayBackground < 1) 
-	      delayBackground = 1;
+      //Max 1 year
+      if(delayBackground > 525600) 
+	      delayBackground = 525600;
+      //Min 0 minute with this value should inactive
+      if(delayBackground < 0) 
+	      delayBackground = 0;
       
       //Mode Background
       if (getUpper(table.Query("Background.Mode")) == "SCALE")
