@@ -65,17 +65,6 @@ void XDesktopContainer::create()
     getRootImage();
 }
 
-/// handles X error events
-int handleXError(Display *disp, XErrorEvent *event) {
-    char errtxt[128];
-	
-    XGetErrorText(disp, event->error_code, errtxt, 128);
-    cerr<<"Idesk: X error: "<<errtxt<<"("<<event->error_code<<") opcodes "<<
-        event->request_code<<"/"<<event->minor_code<<endl<<"resource 0x"<<
-        hex<<event->resourceid<<dec<<endl;
-    return False;
-}
-
 void XDesktopContainer::destroy()
 {
     
@@ -115,10 +104,8 @@ void XDesktopContainer::initXWin()
      prop.nitems = strlen(name);
      XSetTextProperty(display, rootWindow, &prop, start);
      
-      // catch x errors
-     XSetErrorHandler(handleXError);
      XSelectInput( display, rootWindow,  PropertyChangeMask| SubstructureNotifyMask);
-     XSync(display,false);
+     XSync(display, false);
      
 }
 
@@ -133,12 +120,14 @@ void XDesktopContainer::initImlib()
 
 void XDesktopContainer::getRootImage()
 {
+     DesktopConfig * dConfig = dynamic_cast<DesktopConfig *>(config);
+     
      
      imlib_context_set_drawable(rootWindow);
-     bg = new XImlib2Background(this,config);
      
-     bg->spareRoot = imlib_create_image_from_drawable( 0 , 0, 0, 
-				widthOfScreen(), heightOfScreen(), 1);
+     bg = new XImlib2Background(this,config);
+    
+     bg->InitSpareRoot(rootWindow);
 	
      if(!bg->IsOneShot()){	
         timer = new Timer(this);
@@ -289,6 +278,10 @@ void XDesktopContainer::eventLoop()
     sn_context = NULL;
     sn_display = NULL; 
     sn_bool_t retval;
+    sn_display = sn_display_new (display,
+        		         error_trap_push,
+				 error_trap_pop);
+
 #endif /* HAVE_STARTUP_NOTIFICATION  */
     
     for(;;)
@@ -302,7 +295,9 @@ void XDesktopContainer::eventLoop()
 	 
           XNextEvent(display, &ev);
 #ifdef HAVE_STARTUP_NOTIFICATION
-	  sn_display_process_event (sn_display, &ev);
+	  if (sn_display != NULL){
+	   sn_display_process_event (sn_display, &ev);
+          }
 #endif /* HAVE_STARTUP_NOTIFICATION  */
           event = ev;
           parseEvent();
@@ -505,18 +500,14 @@ void XDesktopContainer::exeCurrentAction(XIcon * icon)
                         i++)
 		if (actionConfig->getExecuteAction(i)->isOccuring(currentAction)){
 #ifdef HAVE_STARTUP_NOTIFICATION
-			 sn_display = sn_display_new (display,
-					    error_trap_push,
-					    error_trap_pop);
 			if (sn_display != NULL)
 			{
 			  sn_context = sn_launcher_context_new (sn_display, DefaultScreen (display));
 			  if ((sn_context != NULL) && !sn_launcher_context_get_initiated (sn_context))
 			  {
-		           sn_launcher_context_set_binary_name (sn_context, icon->getCommand(i).c_str());
-		           sn_launcher_context_set_name (sn_context, icon->getCommand(i).c_str());
 			   sn_launcher_context_set_name (sn_context, icon->getCommand(i).c_str());
 			   sn_launcher_context_set_description (sn_context, icon->getCommand(i).c_str());
+		           sn_launcher_context_set_binary_name (sn_context, icon->getCommand(i).c_str());
                            sn_launcher_context_set_icon_name(sn_context, icon->getCommand(i).c_str());
 			   
 			   sn_launcher_context_initiate (sn_context,
@@ -525,7 +516,7 @@ void XDesktopContainer::exeCurrentAction(XIcon * icon)
 					   event.xproperty.time);
 			  }
 			}
-#endif /* HAVE_STARTUP_NOTIFICATION  */
+#endif  /*HAVE_STARTUP_NOTIFICATION */
 			runCommand(icon->getCommand(i));
 		}
     }
