@@ -1,3 +1,4 @@
+
 /* vim:tabstop=4:expandtab:shiftwidth=4
  * 
  * Idesk -- XImlib2Background.cpp
@@ -43,6 +44,7 @@ XImlib2Background::XImlib2Background(AbstractContainer * c, AbstractConfig * con
 	
      int d = dConfig->getDelayBackground();
      directory = dConfig->getSourceBackground();
+
 	
      if(d == 0 || directory == "None"){
 	     OneShot = true;
@@ -51,11 +53,11 @@ XImlib2Background::XImlib2Background(AbstractContainer * c, AbstractConfig * con
      srand( (unsigned)time(0) );
      
      if(OneShot){
-	SetOneImage();
-      }else{
-	ScanImages();
-	SetDelay( d );
-      }
+		SetOneImage();
+     }else{
+		ScanImages();
+		SetDelay( d );
+     }
 	
 }
 
@@ -102,7 +104,8 @@ void XImlib2Background::SetOneImage()
 		image = imlib_load_image(file.c_str());
 	}
 	
-	SetMultiImage(image);
+	   if(image)
+	    SetMultiImage(image);
 }
 
 
@@ -136,13 +139,17 @@ void XImlib2Background::SetMultiImage(Imlib_Image image)
       
       pixmap = XCreatePixmap(display, rootWindow , widthOfScreen, heightOfScreen, depth);
       
-      gcv.foreground = gcv.background = BlackPixel(display, screen);
+      string color = dConfig->getColorBackground();
       
-      bgcolor = (char*)dConfig->getColorBackground().c_str();
+      if(color != "None"){
+      	gcv.foreground = gcv.background = BlackPixel(display, screen);
       
-      if (bgcolor && XParseColor(display, colormap , bgcolor, &xcolor) && XAllocColor(display,  colormap, &xcolor)) {
+      	bgcolor = (char*)dConfig->getColorBackground().c_str();
+      
+      	if (bgcolor && XParseColor(display, colormap , bgcolor, &xcolor) && XAllocColor(display,  colormap, &xcolor)) {
 	      gcv.foreground = gcv.background = xcolor.pixel;
-      }
+      	  }
+        }
       
       gc = XCreateGC(display, pixmap, (GCForeground | GCBackground), &gcv);
       
