@@ -169,6 +169,44 @@ Window XImlib2Image::getWindowToolTip()
   return tooltip->getWindow();
 }
 
+void XImlib2Image::setupLayer() {
+  
+    XDesktopContainer * xContainer =
+            dynamic_cast<XDesktopContainer *>(container);
+	    
+    Display *disp = xContainer->getDisplay();
+
+    Atom type = XInternAtom(disp, "_NET_WM_WINDOW_TYPE", false);
+    Atom state = XInternAtom(disp, "_NET_WM_STATE", false);
+    
+    Atom state_atoms[] = {
+        XInternAtom(disp, "_NET_WM_STATE_BELOW", false),
+        XInternAtom(disp, "_NET_WM_STATE_HIDDEN", false),
+        XInternAtom(disp, "_NET_WM_STATE_SKIP_PAGER", false),
+        XInternAtom(disp, "_NET_WM_STATE_SKIP_TASKBAR", false),
+        XInternAtom(disp, "_NET_WM_STATE_STICKY", false)
+    };
+
+    Atom type_atoms =  XInternAtom(disp, "_NET_WM_WINDOW_TYPE_DESKTOP", false);
+
+    XChangeProperty(disp, window, state, XA_ATOM,
+                                 32, PropModeReplace,
+                                 (unsigned char *)(state_atoms), 5);
+    XChangeProperty(disp, window, type, XA_ATOM,
+                                 32, PropModeReplace,
+                                 (unsigned char *)(&type_atoms), 1);
+
+    XChangeProperty(disp, window, state, XA_ATOM,
+                                  32, PropModeReplace,
+                                  (unsigned char *)(state_atoms), 5);
+    
+    XChangeProperty(disp, window, type, XA_ATOM,
+                                  32, PropModeReplace,
+                                  (unsigned char *)(&type_atoms), 1);
+
+}
+
+
 void XImlib2Image::shapeWindow()
 {
 	
